#!/usr/bin/perl

use strict;
use Test::More tests => 36;
use FDN::Common::Logger;

# 1
BEGIN { use_ok('FDN::Sql::DB_Access') }

# 2
BEGIN { use_ok('FDN::Sql::Basic') }

# 3
BEGIN { use_ok('FDN::Sql::DBC') }

# 4
BEGIN { use_ok('FDN::Sql::Plutar::Basic') }

# 5
BEGIN { use_ok('FDN::Sql::Plutar::Constantes') }

# 6
BEGIN { use_ok('FDN::Sql::Plutar::API') }

# 7
BEGIN { use_ok('FDN::Common::Config') }

# 8
$FDN::Common::Config::CONFIG_ROOT = './t/';
my $dbh = do_connect('test');
ok ( defined $dbh, 'do_connect' );

# 9
is ( ref($dbh), 'HASH', 'do_connect' );

my @queries = (
# 10
"DROP TABLE IF EXISTS PLUTAR",

# 11
"CREATE TABLE PLUTAR (
	PLUTAR_ID	INTEGER	NOT NULL	,
	PLUTAR_ACTION	VARCHAR(128)		,
	PLUTAR_ETAT	ENUM('waiting','runing','done', 'failed', 'canceled'),
	
	PLUTAR_DTMOD	TIMESTAMP(14)			,
	PLUTAR_DTDO	TIMESTAMP(14)			,
	PLUTAR_DTWAIT	TIMESTAMP(14)			,
	PLUTAR_DTRUN	TIMESTAMP(14)			,
	PLUTAR_DTDONE	TIMESTAMP(14)			,
	PLUTAR_DTFAILED	TIMESTAMP(14)			,
	PLUTAR_CANCELED	TIMESTAMP(14)			,

	PLUTAR_NBRUN	INTEGER	NOT NULL DEFAULT 0	,
	
	PRIMARY KEY (PLUTAR_ID)	
)",

# 12
"replace INTO SEQ VALUES ('PLUTAR_ID', 0, 0, 2147483647, 1, 0)",

# 13
"DROP TABLE IF EXISTS PROPPLUTAR",

# 14
"CREATE TABLE PROPPLUTAR (
  PROPPLUTAR_ID int(11) NOT NULL default '0',
  PLUTAR_ID int(11) default NULL,
  PROPPLUTAR_NOM varchar(70) default NULL,
  PROPPLUTAR_VAL text,
  PROPPLUTAR_PAR int(11) default NULL,
  PRIMARY KEY  (PROPPLUTAR_ID),
  KEY idx_propplutar_id (PROPPLUTAR_ID)
)",

# 15
"replace INTO SEQ VALUES ('PROPPLUTAR_ID', 0, 0, 2147483647, 1, 0)"
);

my $res;
for my $q ( @queries ) {
	$res = sql_transaction($dbh,'create',$q);
	ok ( $res->{'ok'}, 'init plutar db');
}

# 16
$res = plutar_select_db('test');
ok ( $res, 'plutar_select_db' );

# 17
my $args = {
	'clef' => 'val',
	'autre' => 'truc',
	'return' => 'success'
};
$res = new_plutar('essai','now');
is ( $res, 1, 'plutar_task' );

# 18-20
$res = first_plutar();
is ( ref($res), 'HASH', 'first_plutar' );
is ( $res->{'PLUTAR_ID'}, 1, 'first_plutar' );
is ( $res->{'PLUTAR_ACTION'}, 'essai', 'first_plutar' );

# 21-23
$res = plutar_par_id(1);
is ( ref($res), 'HASH', 'plutar_par_id');
is ( $res->{'PLUTAR_ID'}, 1, 'plutar_par_id' );
is ( $res->{'PLUTAR_ACTION'}, 'essai', 'plutar_par_id' );

# 24
$res = update_task_field(1,'ACTION','autre');
ok ( $res, 'update_task_field' );

# 25
$res = plutar_par_id(1);
is ( $res->{'PLUTAR_ACTION'}, 'autre', 'update_task_field' );

# 26
$res = update_task_field(1,'ACTION','essai');
ok ( $res, 'update_task_field');

# 27,28
set_plutar_properties(1,$args);
$res = get_plutar_properties(1);
is ( ref($res), 'HASH', 'get_plutar_properties');
is_deeply ( $res, $args, 'set_plutar_properties');

# 29
$res = lock_plutar();
ok ( $res, 'lock_plutar' );

# 30
$res = unlock_plutar();
ok ( $res, 'unlock_plutar' );

error "No error now";

# 31,32
$res = plutar_par_propplutar('autre','truc');
is ( ref($res), 'HASH', 'plutar_par_propplutar');
is ( $res->{'PLUTAR_ID'}, 1, 'plutar_par_propplutar' );

# 33
$res = [ plutar_par_propplutar('autre','truc') ];
is ( $#$res, 0, 'plutar_par_propplutar' );

# 34
$args->{'clef'} = 'newval';
update_plutar_properties(1,$args);
$res = get_plutar_properties(1);
is_deeply($res,$args,'update_plutar_properties');

# 35,36
$res = update_task_dt(1,'DTDO','DATE_ADD("2001-01-01 10:00:00", INTERVAL 101 SECOND)');
ok ( $res, 'update_task_dt');
$res = plutar_par_id(1);
is ( $res->{'PLUTAR_DTDO'}, '2001-01-01 10:01:41', 'update_task_dt');

